import * as logger from './log'
import { mqttHandler } from './MqttDispatcher'
import { AItem } from './AItem'

export class MySwitchSingleItem {
    private actionTopic: string

    constructor(actionTopic: string) {
        this.actionTopic = actionTopic
    }

    processMessage(topic: string, payload: string) {
        switch(payload) {
            case 'PRESS_SHORT':
                mqttHandler.send(this.actionTopic, 'SHORT', true)
                break
            case 'PRESS_LONG_START':
            case 'PRESS_LONG_CONT':
                mqttHandler.send(this.actionTopic, 'LONG_HOLD', true)
                break
            case 'PRESS_LONG_END':
                mqttHandler.send(this.actionTopic, 'LONG_END', true)
                break
            default:
                logger.warn(`HM4BSI: no handling available for ${topic}`)
                break
        }
    }
}

export class MySwitchThing extends AItem {
    private itemObjs: MySwitchSingleItem[]

    constructor(floor: string, room: string, item: string, itemObjs: MySwitchSingleItem[]) {
        super(floor, room, item, '')
        this.itemObjs = itemObjs
        if (this.itemObjs.length != 3) {
            throw new Error('itemObjs for MySwitchThing must have three elements')
        }
        this.subscribeTopics = [
            `${this.topicFirstPart}/#` 
        ]
    }

    processMessage(topic: string, payload: string) {
        logger.info(`MyT: ${topic}, ${payload}`)
        let buttonIdx = parseInt(topic.substring(this.topicFirstPart.length+1))
        if (buttonIdx >= 1 && buttonIdx <= 3) {
            this.itemObjs[buttonIdx-1].processMessage('', payload)
        } else {
            logger.warn(`MyT: no handling available for ${topic}, ${buttonIdx}`)
        }
    }
}


