import { AItem, HasFeedbackTopic } from './AItem'
import { mqttHandler } from './MqttDispatcher'
import * as logger from './log'

enum SignalState {
    SIGNAL_RED,
    SIGNAL_GREEN,
    SIGNAL_UNKNOWN,
}

class SignalItem {
    private item: HasFeedbackTopic
    private signalState: SignalState
    private redToken: string
    private greenToken: string

    constructor(item: HasFeedbackTopic, redToken: string, greenToken: string) {
        this.item = item
        this.signalState = SignalState.SIGNAL_UNKNOWN
        this.redToken = redToken
        this.greenToken = greenToken
    }

    getSignalState() : SignalState {
        return this.signalState
    }

    processMessage(topic: string, payload: string): void {
        if (topic == this.item.getStateFeedbackTopic()) {
            logger.info(`${topic}, ${payload}`)
            if (payload == this.greenToken) {
                this.signalState = SignalState.SIGNAL_GREEN
            } else if (payload == this.redToken) {
                this.signalState = SignalState.SIGNAL_RED
            } else {
                this.signalState = SignalState.SIGNAL_UNKNOWN
            }
            // logger.info(`DBG: SignalItem: ${topic}, ${payload}, ${this.signalState}`)
        }
    }
}

export class TwoLedSignal extends AItem  {
    private led1Items: SignalItem[] = []
    private led2Items: SignalItem[] = []

    constructor(floor: string, room: string, item: string, label: string, 
        led1Items: HasFeedbackTopic[], led1GreenToken: string, led1RedToken: string,
        led2Items: HasFeedbackTopic[], led2GreenToken: string, led2RedToken: string) {

        super(floor, room, item, label)

        this.subscribeTopics = []
        led1Items.forEach((item: HasFeedbackTopic) => {
            this.led1Items.push(new SignalItem(item, led1RedToken, led1GreenToken))
            this.subscribeTopics.push(item.getStateFeedbackTopic())
        })
        led2Items.forEach((item: HasFeedbackTopic) => {
            this.led2Items.push(new SignalItem(item, led2RedToken, led2GreenToken))
            this.subscribeTopics.push(item.getStateFeedbackTopic())
        })
    }


    processMessage(topic: string, payload: string) : void {
        let reds : number = 0
        const RED_VALUES : SignalState[] = [SignalState.SIGNAL_RED, SignalState.SIGNAL_UNKNOWN]

        this.led1Items.forEach((item: SignalItem) => {
            item.processMessage(topic, payload)
            if (RED_VALUES.indexOf(item.getSignalState()) != -1) {
                reds++
            }
            // logger.info(`DBG: TwoLedSignal ${item.getSignalState()}, ${reds}`)
        })
        let msg = (reds > 0) ? "red" : "green"
        mqttHandler.send(`${this.topicFirstPart}/led1`, msg)

        reds = 0
        this.led2Items.forEach((item: SignalItem) => {
            item.processMessage(topic, payload)
            if (RED_VALUES.indexOf(item.getSignalState()) != -1) {
                reds++
            }
            // logger.info(`DBG: TwoLedSignal ${item.getSignalState()}, ${reds}`)
        })
        msg = (reds > 0) ? "red" : "green"
        mqttHandler.send(`${this.topicFirstPart}/led2`, msg)
    }
}
